#
# Based on ROSA Linux 2016.1 mGBA package
# https://abf.rosalinux.ru/import/mgba/blob/rosa2016.1/mgba.spec
# spec file classified as "code" and released under MIT License
# "Modern Style with sublicense" per ROSA Contributor License Agreement.
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

%global debug_package %{nil}

Name:             mgba
Summary:          Game Boy Advance emulator
Version:          0.6.1
Release:          2.4
Group:            System/Emulators
License:          MPL-2.0
URL:              https://mgba.io/
Source0:          %{name}-%{version}.tar.xz

BuildRequires:    cmake
BuildRequires:    gcc-c++
BuildRequires:    pkgconfig(epoxy)
BuildRequires:    pkgconfig(gl)
BuildRequires:    pkgconfig(glu)
BuildRequires:    pkgconfig(ice)
BuildRequires:    pkgconfig(libpng)
BuildRequires:    pkgconfig(libzip)
BuildRequires:    pkgconfig(Qt5Core)
BuildRequires:    pkgconfig(Qt5Multimedia)
BuildRequires:    pkgconfig(Qt5OpenGL)
BuildRequires:    pkgconfig(Qt5Widgets)
BuildRequires:    pkgconfig(sdl2)
BuildRequires:    pkgconfig(sm)
BuildRequires:    pkgconfig(x11)
BuildRequires:    pkgconfig(zlib)
BuildRequires:    desktop-file-utils
Requires(post):   hicolor-icon-theme
Requires(postun): hicolor-icon-theme


%description
mGBA is a new generation of Game Boy Advance emulator with the goal
of being fast enough to run on lower end hardware.
Other goals include accurate enough emulation to provide a development
environment for homebrew software, a good workflow for tool-assist
runners, and a modern feature set for emulators that older emulators
may not support.

#----------------------------------------------------------------------------

%package sdl
Summary:  Game Boy Advance (GBA) emulator (SDL2-based CLI version)
Group:    System/Emulators

%description sdl
Game Boy Advance (GBA) emulator with the goal of being fast enough to run on
lower end hardware than other emulators support, without sacrificing accuracy
or portability. Other goals include accurate enough emulation to provide a
development environment for homebrew software, a good workflow for tool-assist
runners, and a modern feature set for emulators that older emulators may not
support.

This package provides SDL2-based CLI version of mGBA.

%files sdl
%{_bindir}/%{name}
%{_mandir}/man6/mgba.6*

#----------------------------------------------------------------------------

%prep
%setup -q

%build
mkdir build
cd build
cmake \
    -DBUILD_SHARED:BOOL=ON \
    -DBUILD_STATIC:BOOL=OFF \
    -DCMAKE_INSTALL_PREFIX:PATH=/usr \
    -DCMAKE_SKIP_RPATH=ON \
    -DUSE_FFMPEG:BOOL=OFF \
    -DUSE_MAGICK:BOOL=OFF \
    ..

%install
make install DESTDIR=%{buildroot} -C build

# rather use %%doc and remove leftover file
rm -rf %{buildroot}/usr/share/doc/mGBA/
rm -rf %{buildroot}/usr/include/mgba

%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGES LICENSE README.md
%{_libdir}/libmgba.*
%{_bindir}/%{name}-qt
%{_datadir}/applications/%{name}-qt.desktop
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_mandir}/man6/mgba-qt.6*

%changelog
* Mon Nov 27 2017 opensuse-packaging@opensuse.org
- Update to version 0.6.1:
  * Res: Update patrons for October
  * CMake: Update patch level
  * Update CHANGES for 0.6.1
  * Qt: Hide mouse immediately when loading
  * Test: Fix test suite post-Cheats
  * GBA Cheats: Fix PARv3 multiline blocks (fixes #889)
  * GBA Cheats: Slightly improve PARv3 detection
  * GBA Cheats: Improve detection of raw cheats
  * GB Video: Fix read mode when enabling LCD
  * VFS: Make VFile.truncate work growing files on PSV (fixes #885)
* Mon Nov 27 2017 kamikazow@opensuse.org
- Update to version 0.6.1:
  * VFS: Make VFile.truncate work growing files on PSV (fixes #885)
  * GB Video: Fix read mode when enabling LCD
  * GBA Cheats: Improve detection of raw cheats
  * GBA Cheats: Slightly improve PARv3 detection
  * GBA Cheats: Fix PARv3 multiline blocks (fixes #889)
  * Test: Fix test suite post-Cheats
  * Qt: Hide mouse immediately when loading
  * Update CHANGES for 0.6.1
  * CMake: Update patch level
  * Res: Update patrons for October
- Fix Fedora 27 build
* Sun Jul 16 2017 kamikazow@opensuse.org
- Update to version 0.6.0:
  * Drop mgba-0.5.0-linkage.patch
  * All: Do not install hicolor icons on Haiku.
  * All: Use more GNUInstallDirs & don't install shaders if no GL.
  * Core: Fix exiting rewind thread
  * Qt: Updated Spanish translation
  * SDL: Fix showing version number (fixes #794)
  * All: Minor text fixes
  * SDL: Fix cheats not loading
  * Qt: Fix screen background improperly stretching
  * All: Minor text fixes
  * All: Update CHANGES for 0.6.0
* Wed Jul 12 2017 kamikazow@opensuse.org
- Update to version 0.6b1:
  * Fixes compilation on recent Tumbleweed snapshots
  * Core: Improved threading interrupted detection
  * GB MBC: Fix MBC7 sampling
  * Python: GB core should expose memory
  * Python: Improve GB SIO bindings
  * LR35902: Fix decoding CB commands
  * LR35902: Switch memory disassembly syntax to rgbds-style
  * Core: Fix directory sets crashing on close if base isn't properly detached
  * All: Revert setting minimum macOS version to 10.5
  * GB Timer: Fix order-of-operations between & and +
  * All: Update changes for 0.6 beta 1
* Tue Jan 24 2017 kamikazow@opensuse.org
- Ported ROSA Linux package to Fedora and openSUSE
